# Base Attacks

::: agentdojo.attacks.base_attacks.BaseAttack
    options:
        filters: []
        heading_level: 2

::: agentdojo.attacks.base_attacks.DEFAULT_USER_NAME
    options:
        filters: []
        heading_level: 2

::: agentdojo.attacks.base_attacks.DEFAULT_MODEL_NAME
    options:
        filters: []
        heading_level: 2

::: agentdojo.attacks.base_attacks.FixedJailbreakAttack
    options:
        filters: ["!attack"]
        heading_level: 2
